@@ -19,7 +19,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: affile.c,v 1.61 2003/09/04 09:34:31 bazsi Exp $
+ * $Id: affile.c,v 1.61.4.1 2004/01/13 18:08:02 bazsi Exp $
  *
  ***************************************************************************/
  
@@ -92,45 +92,45 @@ static int do_open_file(struct ol_string *name, int flags,
                         int dir_uid, int dir_gid, int dir_mode,
                         int create_dirs, int *fd)
 {
-	if (strstr(name->data, "../") ||
-	    strstr(name->data, "/..")) {
+	if (strstr((char *) name->data, "../") ||
+	    strstr((char *) name->data, "/..")) {
 		werror("Spurious path %S, logfile not created\n", name);
 		return 0;
 	}
-	if (strncmp(name->data, "/dev", 4) == 0) {
+	if (strncmp((char *) name->data, "/dev", 4) == 0) {
 		werror("Changing permissions on special file %S\n", name);
 	}
 
-	*fd = open(name->data, flags, mode != -1 ? mode : 0600);
+	*fd = open((char *) name->data, flags, mode != -1 ? mode : 0600);
 	if (create_dirs && *fd == -1 && errno == ENOENT) {
 		/* directory does not exist */
-		char *p = name->data + 1;
+		char *p = (char *) name->data + 1;
 
 		p = strchr(p, '/');
 		while (p) {
 			struct stat st;
 			*p = 0;
-			if (stat(name->data, &st) == 0) {
+			if (stat((char *) name->data, &st) == 0) {
 				if (!S_ISDIR(st.st_mode))
 					return 0;
 			}
 			else if (errno == ENOENT) {
-				if (mkdir(name->data, dir_mode != -1 ? dir_mode : 0700) == -1)
+				if (mkdir((char *) name->data, dir_mode != -1 ? dir_mode : 0700) == -1)
 					return 0;
 				if (dir_uid != -1 || dir_gid != -1)
-					chown(name->data, dir_uid, dir_gid);
+					chown((char *) name->data, dir_uid, dir_gid);
 				if (dir_mode != -1)
-					chmod(name->data, dir_mode);
+					chmod((char *) name->data, dir_mode);
 			}
 			*p = '/';
 			p = strchr(p + 1, '/');
 		}
-		*fd = open(name->data, flags, mode);
+		*fd = open((char *) name->data, flags, mode);
 	}
 	if (uid != -1 || gid != -1)
-		chown(name->data, uid, gid);
+		chown((char *) name->data, uid, gid);
 	if (mode != -1)
-		chmod(name->data, mode);
+		chmod((char *) name->data, mode);
 	return *fd != -1;
 }
 
@@ -271,9 +271,9 @@ do_init_dest_writer(struct log_handler *c, struct syslog_config *cfg, struct per
                 struct stat st;
                 time_t now = time(NULL);
 
-                if (stat(self->expanded_fname->data, &st) == 0) {
+                if (stat((char *) self->expanded_fname->data, &st) == 0) {
                         if ((now-st.st_mtime) >= ((self->owner->remove_if_older))) {
-                                unlink(self->expanded_fname->data);
+                                unlink((char *) self->expanded_fname->data);
                         }
                 }  
         }
