@@ -19,7 +19,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: afinet.c,v 1.23 2003/01/31 09:39:59 bazsi Exp $
+ * $Id: afinet.c,v 1.25.4.1 2004/01/13 18:08:02 bazsi Exp $
  *
  ***************************************************************************/
 
@@ -39,6 +39,7 @@ int deny_severity = 0;
 #endif
 
 #include "afinet.c.x"
+#include "macros.h"
 
 void inet_address_setip(struct address_info **a, const char *ip)
 {
@@ -271,7 +272,7 @@ do_init_afinet_source(struct log_handler *c,
 		persistent_name = c_format("afinet_%z_%S_%i", 
 					   self->super.flags & AFSOCKET_DGRAM ? "dgram" : "stream",
 					   inet_addr->ip, inet_addr->port);
-		p_info = find_persistent_info(persistent, persistent_name->length, persistent_name->data);
+		p_info = find_persistent_info(persistent, persistent_name->length, (char *) persistent_name->data);
 		ol_string_free(persistent_name);
 
 		if (p_info) {
@@ -386,6 +387,8 @@ struct log_source_driver *make_afinet_source(struct address_info *bind_addr, UIN
        (dest_buf object abstract_buffer)
        (sync_freq simple UINT32)
        (conn_fd object connect_fd)
+       (template_output string)
+       (template_escape . int)
        (cfg object syslog_config)))
 */
 /* af_inet destination */
@@ -422,6 +425,20 @@ void afinet_dest_set_localport(struct log_dest_driver *c, UINT32 port,
 	inet_address_setport(&dest->bind_addr, port, service, proto);
 }
 
+void afinet_dest_set_template(struct log_dest_driver *c, char *t)
+{
+	CAST(afinet_dest, self, c);
+ 
+	self->template_output = c_format("%z", t);
+}
+
+void afinet_dest_set_template_escape(struct log_dest_driver *c, int enable)
+{
+	CAST(afinet_dest, self, c);
+
+	self->template_escape = enable;
+}
+
 void afinet_dest_set_destport(struct log_dest_driver *c, UINT32 port, 
 			      const char *service, const char *proto)
 {
@@ -473,13 +490,10 @@ static int do_init_afinet_dest(struct log_handler *c,
 		return ST_OK | ST_GOON;
 	}
 	else {
-		if (errno == ECONNREFUSED) {
-			io_callout(self->cfg->backend, 
-				   self->cfg->time_reopen, 
-				   make_driver_reinit(&self->super.super.super, self->cfg));
-			return ST_OK | ST_GOON;
-		}
-		werror("Error creating AF_INET socket (%z)\n", strerror(errno));
+		io_callout(self->cfg->backend, 
+			   self->cfg->time_reopen, 
+			   make_driver_reinit(&self->super.super.super, self->cfg));
+		return ST_OK | ST_GOON;
 	}
 	return ST_FAIL | ST_QUIT;
 }
@@ -528,7 +542,21 @@ void do_handle_afinet_dest(struct log_handler *c, struct log_info *msg)
 	CAST(afinet_dest, self, c);
 
 	if (self->dest_buf) {
-		A_WRITE_STRING(&self->dest_buf->super, c_format("<%i>%S %S %S\n", msg->pri, msg->date, msg->host, msg->msg));
+		struct ol_string *msg_line;
+
+		if (self->template_output) {
+			msg_line = c_format("<%i>%fS",
+					    msg->pri,
+					    expand_macros(
+						    self->cfg,
+						    self->template_output,
+						    self->template_escape, msg));
+		} else {
+                	msg_line = c_format("<%i>%S %S %S\n",
+					    msg->pri,
+					    msg->date, msg->host, msg->msg);
+		}
+		A_WRITE_STRING(&self->dest_buf->super, msg_line);
 	}
 	log_info_free(msg);
 }
