@@ -19,7 +19,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: afsocket.h,v 1.15 2001/04/14 09:10:34 bazsi Exp $
+ * $Id: afsocket.h,v 1.16 2003/01/31 14:26:48 bazsi Exp $
  *
  ***************************************************************************/
 
@@ -138,12 +138,16 @@ void afinet_dest_set_auth(struct log_dest_driver *c, UINT32 value);
 void afinet_dest_set_mac(struct log_dest_driver *c, UINT32 value);
 void afinet_dest_set_encrypt(struct log_dest_driver *c, UINT32 value);
 void afinet_dest_set_syncfreq(struct log_dest_driver *c, UINT32 value);
+void afinet_dest_set_template(struct log_dest_driver *c, char *t);
+void afinet_dest_set_template_escape(struct log_dest_driver *c, int enable);
 
 struct log_source_driver *
 make_afunix_source(struct address_info *bind_addr, UINT32 flags);
 
 struct log_dest_driver *
 make_afunix_dest(struct address_info *dest_addr, UINT32 flags);
+void afunix_dest_set_template(struct log_dest_driver *c, char *t);
+void afunix_dest_set_template_escape(struct log_dest_driver *c, int enable);
 
 struct log_source_driver *
 make_afinet_source(struct address_info *bind_addr, UINT32 flags);
