@@ -19,7 +19,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: afstreams.c,v 1.14 2002/08/21 14:03:50 bazsi Exp $
+ * $Id: afstreams.c,v 1.16 2003/01/20 15:28:35 bazsi Exp $
  *
  ***************************************************************************/
 
@@ -77,6 +77,7 @@ static struct door_fd *make_door_fd(int fd)
      (name stream_fd)
      (super nonblocking_fd)
      (vars
+       (bad_hostname special-struct regex_t #f regfree)
        (pipe object log_handler)))
 */
 
@@ -145,7 +146,7 @@ static void stream_read_callback(struct nonblocking_fd *fd)
 			
 			length = eol - bol;
 			if (length) {
-				li = make_log_info(length, bol, NULL, 0);
+				li = make_log_info(length, bol, NULL, 0, &self->bad_hostname);
 				li->pri = pri;
 				HANDLE_LOG(self->pipe, li);
 			}
@@ -160,6 +161,7 @@ static void stream_read_callback(struct nonblocking_fd *fd)
 
 struct nonblocking_fd *io_stream_get(struct io_backend *backend,
 				     int fd, 
+				     UINT8 *hostname_re,
 				     struct log_handler *pipe)
 {
 	NEW(stream_fd, f);
@@ -169,6 +171,10 @@ struct nonblocking_fd *io_stream_get(struct io_backend *backend,
 	f->super.read = stream_read_callback;
 	f->super.want_read = 1;
 	f->pipe = pipe;
+	if (hostname_re == NULL)
+		regcomp(&f->bad_hostname, "^$", REG_NOSUB | REG_EXTENDED);
+	else
+		regcomp(&f->bad_hostname, hostname_re, REG_NOSUB | REG_EXTENDED);
 
 	return &f->super;
 }
@@ -220,7 +226,7 @@ do_init_afstreams_source(struct log_handler *c,
 			close(fd);
 			return ST_FAIL | ST_QUIT;
 		}
-		self->stream_fd = io_stream_get(cfg->backend, fd, c);
+		self->stream_fd = io_stream_get(cfg->backend, fd, cfg->bad_hostname, c);
 
 		REMEMBER_RESOURCE(cfg->resources, &self->stream_fd->super);
 
