@@ -19,7 +19,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: afunix.c,v 1.26 2003/01/31 09:39:59 bazsi Exp $
+ * $Id: afunix.c,v 1.27.4.1 2004/01/13 18:08:02 bazsi Exp $
  *
  ***************************************************************************/
 
@@ -40,6 +40,8 @@
 #include <assert.h>
 
 #include "afunix.c.x"
+#include "macros.h"
+
 
 /* af_unix source connection */
 
@@ -193,7 +195,7 @@ int do_init_afunix_source(struct log_handler *c,
 		struct persistent_info *p_info;
 
 		persistent_name = c_format("afunix_stream_%S", unix_addr->path);
-		p_info = find_persistent_info(persistent, persistent_name->length, persistent_name->data);
+		p_info = find_persistent_info(persistent, persistent_name->length, (char *) persistent_name->data);
 		ol_string_free(persistent_name);
 
 		if (p_info) {
@@ -223,8 +225,8 @@ int do_init_afunix_source(struct log_handler *c,
 		return ST_QUIT | ST_FAIL;
 	}
 
-	chown(unix_addr->path->data, self->uid, self->gid);
-	chmod(unix_addr->path->data, self->perm);
+	chown((char *) unix_addr->path->data, self->uid, self->gid);
+	chmod((char *) unix_addr->path->data, self->perm);
 
 	switch (self->super.flags & 0x0003) {
 	case AFSOCKET_STREAM: {
@@ -316,16 +318,50 @@ make_afunix_source(struct address_info *bind_addr, UINT32 flags)
      (vars
        (dest object io_fd)
        (dest_buf object abstract_buffer)
+       (template_output string)
+       (template_escape . int)
        (cfg object syslog_config)))
 */
 
-void do_handle_afunix_dest(struct log_handler *c, struct log_info *msg)
+void
+afunix_dest_set_template(struct log_dest_driver *c, char *t)
+{
+	CAST(afunix_dest, self, c);
+ 
+	self->template_output = c_format("%z", t);
+}
+
+void
+afunix_dest_set_template_escape(struct log_dest_driver *c, int enable)
+{
+	CAST(afunix_dest, self, c);
+
+	self->template_escape = enable;
+}
+
+static void
+do_handle_afunix_dest(struct log_handler *c, struct log_info *msg)
 {
 	CAST(afunix_dest, self, c);
 
 	if (self->dest_buf) {
-		A_WRITE_STRING(&self->dest_buf->super, c_format("<%i>%S %S%c", msg->pri, msg->date, msg->msg, 0));
+		struct ol_string *msg_line;
+
+		if (self->template_output) {
+			msg_line = c_format("<%i>%fS",
+					    msg->pri,
+					    expand_macros(
+						    self->cfg,
+						    self->template_output,
+						    self->template_escape, msg));
+		} else {
+                	msg_line = c_format("<%i>%S %S %S\n",
+					    msg->pri,
+					    msg->date, msg->host, msg->msg);
+		}                
+		A_WRITE_STRING(&self->dest_buf->super, msg_line);
 	}
+
 	log_info_free(msg);
 }
 
