@@ -115,7 +115,7 @@ UINT32 last_pad_size;
 UINT8 *
 get_last_log_prefix(void)
 {
-	char *res = last_prefix;
+	UINT8 *res = last_prefix;
 	last_prefix = NULL;
 	return res;
 }
@@ -1523,7 +1523,7 @@ case 21:
     break;
 case 24:
 #line 237 "cfg-grammar.y"
-{ last_prefix = yyvsp[-1].cptr; }
+{ last_prefix = (UINT8 *) yyvsp[-1].cptr; }
     break;
 case 25:
 #line 238 "cfg-grammar.y"
