@@ -53,7 +53,7 @@ typedef union {
 # define	KW_DIR_OWNER	296
 # define	KW_DIR_GROUP	297
 # define	KW_DIR_PERM	298
-# define	KW_FILE_TEMPLATE	299
+# define	KW_TEMPLATE	299
 # define	KW_TEMPLATE_ESCAPE	300
 # define	KW_OWNER	301
 # define	KW_GROUP	302
