@@ -19,7 +19,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: cfgfile.c,v 1.40 2003/01/08 09:31:37 bazsi Exp $
+ * $Id: cfgfile.c,v 1.40.4.1 2004/01/13 18:08:02 bazsi Exp $
  *
  ***************************************************************************/
 
@@ -127,7 +127,7 @@ void cfg_set_dir_perm(int perm)
 
 void cfg_set_bad_hostname(char *bad_hostname)
 {
-	configuration->bad_hostname = bad_hostname;
+	configuration->bad_hostname = (UINT8 *) bad_hostname;
 }
 
 struct persistent_info *
@@ -162,7 +162,7 @@ void add_persistent_info(struct persistent_config *c,
 {
 	struct persistent_info *p;
 
-	p = find_persistent_info(c, node->name->length, node->name->data);
+	p = find_persistent_info(c, node->name->length, (char *) node->name->data);
 	assert(!p);
 
 	node->next = c->nodes;
@@ -193,7 +193,7 @@ do \
 { \
         for (s = first; s; s = s->next) { \
 	         if (i->name->length == s->name->length && \
-		     strncmp(i->name->data, s->name->data, i->name->length) == 0) { \
+		     strncmp((char *) i->name->data, (char *) s->name->data, i->name->length) == 0) { \
 			 i->ref = (struct ol_object *) s; \
 			 break; \
 		 } \
