@@ -19,7 +19,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: cfgfile.h,v 1.25 2002/10/18 12:31:08 bazsi Exp $
+ * $Id: cfgfile.h,v 1.26 2003/01/08 09:31:37 bazsi Exp $
  *
  ***************************************************************************/
 
@@ -57,6 +57,7 @@
 	(use_fqdn simple UINT32)
 	(use_dns simple UINT32)
 	(check_hostname simple UINT32)
+	(bad_hostname pointer UINT8)
 	(create_dirs simple UINT32)
 	(uid simple int)
 	(gid simple int)
@@ -129,10 +130,7 @@ void cfg_set_perm(int perm);
 void cfg_set_dir_owner(char *uid);
 void cfg_set_dir_group(char *gid);
 void cfg_set_dir_perm(int perm);
-
-
-
-
+void cfg_set_bad_hostname(char *bad_hostname);
 
 
 struct syslog_config *make_syslog_config(const char *name, struct io_backend *backend);
