@@ -19,7 +19,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: macros.c,v 1.4.4.1 2004/01/09 09:21:08 bazsi Exp $
+ * $Id: macros.c,v 1.4.4.2 2004/01/13 18:08:02 bazsi Exp $
  *
  ***************************************************************************/
 
@@ -76,7 +76,7 @@
 
 
 static int
-append_string(char **dest, int *left, char *str, int length, int escape)
+append_string(char **dest, unsigned int *left, char *str, int length, int escape)
 {
 	int l;
   
@@ -161,7 +161,7 @@ expand_macro(struct syslog_config *cfg, int id, int escape, char **dest, unsigne
 	case M_FULLHOST: {
 		struct ol_string *host = (id == M_FULLHOST ? msg->host : msg->host_from);
 		/* full hostname */
-		length = append_string(dest, left, host->data, host->length, escape);
+		length = append_string(dest, left, (char *) host->data, host->length, escape);
 		break;
 	}
 	case M_HOST_FROM:
@@ -185,13 +185,13 @@ expand_macro(struct syslog_config *cfg, int id, int escape, char **dest, unsigne
 		else {
 			length = MIN(*left, (unsigned int) (host->length - (p1 - host->data)));
 		}
-		length = append_string(dest, left, p1, length, escape);
+		length = append_string(dest, left, (char *) p1, length, escape);
 		break;
 	}
 	case M_PROGRAM: {
 		/* program */
 		if (msg->program) {
-			length = append_string(dest, left, msg->program->data, msg->program->length, escape);
+			length = append_string(dest, left, (char *) msg->program->data, msg->program->length, escape);
 		}
 		break;
 	}
@@ -352,7 +352,7 @@ expand_macro(struct syslog_config *cfg, int id, int escape, char **dest, unsigne
 	}
 	case M_MESSAGE: {
 		/* message */
-		length = append_string(dest, left, msg->msg->data, msg->msg->length, escape);
+		length = append_string(dest, left, (char *) msg->msg->data, msg->msg->length, escape);
 		break;
 	}
 	default:
@@ -514,7 +514,7 @@ expand_macros(struct syslog_config *cfg, struct ol_string *template, int templat
 				template->data[i] <= 'Z') ||
 			       template->data[i] == '_') 
 				i++;
-			m = find_macro(&template->data[start], i - start);
+			m = find_macro((char *) &template->data[start], i - start);
 			if (m) {
 				expand_macro(cfg, m->id, template_escape, &format_ptr, &left, msg);
 			}
