@@ -19,7 +19,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: sources.c,v 1.37 2003/01/08 09:31:37 bazsi Exp $
+ * $Id: sources.c,v 1.37.4.1 2004/01/13 18:08:02 bazsi Exp $
  *
  ***************************************************************************/
 
@@ -173,7 +173,7 @@ make_log_reader(UINT32 dgram,
 	if (hostname_re == NULL)
 		regcomp(&self->bad_hostname, "^$", REG_NOSUB | REG_EXTENDED);
 	else
-		regcomp(&self->bad_hostname, hostname_re, REG_NOSUB | REG_EXTENDED);
+		regcomp(&self->bad_hostname, (char *) hostname_re, REG_NOSUB | REG_EXTENDED);
 	return &self->super;
 }
 
