@@ -19,7 +19,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: syslog-names.c,v 1.7 2001/02/24 12:38:03 bazsi Exp $
+ * $Id: syslog-names.c,v 1.8 2002/10/18 12:31:08 bazsi Exp $
  *
  ***************************************************************************/
 
@@ -71,7 +71,7 @@ struct sl_name sl_facilities[] = {
 	{ NULL, -1 }
 };
 
-int syslog_lookup_name(const char *name, struct sl_name names[])
+unsigned int syslog_lookup_name(const char *name, struct sl_name names[])
 {
 	int i;
 
@@ -83,7 +83,7 @@ int syslog_lookup_name(const char *name, struct sl_name names[])
 	return -1;
 }
 
-char *syslog_lookup_value(int value, struct sl_name names[])
+char *syslog_lookup_value(unsigned int value, struct sl_name names[])
 {
 	int i;
 
